# NativeScript NA Slideshow plugin

**NOTE! Android is currently not supported.**

## Installation

`npm i nativescript-na-slideshow --save`

## Usage

### XML

Slides can be added manually inside the XML as below:

```xml
<AbsoluteLayout id="slideShow" loaded="load_slideShow">
  <GridLayout backgroundColor="#ffffff">
    <Label text="Slide 1" horizontalAlignment="center" />
  </GridLayout>
  <GridLayout backgroundColor="#f2f2f2">
    <Label text="Slide 2" horizontalAlignment="center" />
  </GridLayout>
  <GridLayout backgroundColor="#ffffff">
    <Label text="Slide 3" horizontalAlignment="center" />
  </GridLayout>
</AbsoluteLayout>
```

It is important that the slide container is an `AbsoluteLayout` or else problems will occur. Slides can also, instead of being static like above, be created using an `ObservableArray`. To do this, the container has to stay empty - as such:

```xml
<AbsoluteLayout id="slideShow" loaded="load_slideShow" />
```

Before heading to the JavaScript part, make sure the `loaded` attribute is set as in the example: `loaded="load_slideShow"`. This is needed for the JavaScript code to turn the container into a slideshow.

### JS

Once the XML has been set up, the plugin will now be able to transform the container into a slideshow. To do this, see below:

```js
var NASlideShow = require("nativescript-na-slideshow");

exports.load_slideShow = function(args) {
  var view = args.object;
  var slideShow = new NASlideShow();
  
  slideShow.init(view);
};
```

Once this has been done, the slideshow is now up and running!

### Instance properties

In the JS example above, the `init()` function used the default properties. Here is a list of all properties that exist (showing default values):

```js
{
  items: false, // An ObservableArray instance.
  itemTemplate: "<GridLayout />", // The view template for each slide (has to be written as an XML string). See the Repeater documentation for further information.
  enableBounce: false, // Scroll bouncing disabled by default.
  fallbackWidth: [screen width], // In case the inherited width doesn't load in time.
  fallbackHeight: [screen height], // In case the inherited height doesn't load in time.
  indicators: {
    position: "bottom", // The position of the indicators. Available options are "bottom" and "top".
    size: 10, // The indicators' size.
    color: "#808080", // The indicators' color.
    borderWidth: 0, // The indicators' border width.
    borderColor: "#404040", // The indicators' border color.
    forceVisibility: false, // By default, indicators will only show up if there are 2 slides or more.
    disable: false // Disable the indicators.
  }
}
```

The **itemTemplate** property is special because, according to the [Repeater documentation](https://docs.nativescript.org/api-reference/classes/_ui_repeater_.repeater.html#itemtemplate), it has to be a string in XML format.

The **fallbackWidth** and **fallbackHeight** properties are sometimes needed when the inherited width and height haven't yet been set during view loaded state.

### Methods

#### init()

This must be called to initiate the slideshow view.

`init(template, props)`

- **template** - The view container (template) that is going to become the slideshow.
- **props** - Set any instance properties (optional).

```js
var frameModule = require("ui/frame");
var observableArray = require("data/observable-array").ObservableArray;
var container = frameModule.topmost().currentPage.getViewById("slideShow");
var slideShow = new NASlideShow();

slideShow.init(container, {
  items: new ObservableArray("Slide 1", "Slide 2", "Slide 3"),
  itemTemplate: '<GridLayout><Label text="{{ $value }}" horizontalAlignment="center" /></GridLayout>',
  indicators: {
    forceVisibility: true,
    position: "top",
    color: "#ffffff"
  }
});
```

------

#### appendSlide()

Call this to append new slides. Depending on whether the slideshow was initiated using XML only or an `ObservableArray` instance, the view parameter works a little differently.

`appendSlide(slideView, props)`

- **slideView** - The view container/string/object that is going to become the slideshow.
- **props** - Set any instance properties (optional).

**XML**

```js
var GridLayout = require("ui/layouts/grid-layout").GridLayout;
var Label = require("ui/label").Label;

var slideView = new GridLayout();
var textLabel = new Label();
textLabel.text = "Slide 4";
slideView.insertChild(textLabel, 0);

slideShow.appendSlide(slideView, {
  indicator: {
    icon: "+",
    float: true
  }
});
```

**ObservableArray**

```js
slideShow.appendSlide("Slide 4", {
  indicator: {
    icon: "+",
    float: true
  }
});
```

The **props** parameter's defaults are:

```js
{
  indicator: {
    icon: false, // Custom icon (or character) instead of a dot.
    fontFamily: false, // The icon font family.
    float: false // Set to true to make the icon float to the right, as in not adjusting the indicators horizontal alignment.
  }
}
```

------

#### on()

Event listener for each slide scroll. When a slide has finished scrolling, the event will be called.

`on("slideChange", callback)`

- **"slideChange"** - The only available *eventName*.
- **callback** - The callback on each notification.

```js
slideShow.on("slideChange", function(eventData) {
  console.log("Slide index: " + eventData.index);
});
```

The **eventData** parameter inside the callback function contains the following properties:

- **eventName** - The event's name.
- **object** - The slideshow view.
- **index** - The current slide index.
- **length** - The total amount of slides.

------

#### Get methods

- `getSlidesCount()` - Get the total amount of slides.
  - *Returns* `number`
- `getSlideIndex()` - Get the current slide index.
  - *Returns* `number`

------

#### Other properties/methods

- `view` - Returns the slideshow view object (the view container/template that was used to initiate the slideshow).
- `viewsList` - List of all children views:
  - `scrollView` - The ScrollView.
  - `container` - The internal container for the slideshow.
  - `indicators` - The indicators view.
  - `repeater` - The Repeater view (only available when using **ObservableArray**).
- `items` - Returns the **ObservableArray** (only available when using **ObservableArray**).

## Known issues

- No Android compatibility, yet.

## History

**Version 1.1.0** (12 September 2016)

- getSlidesCount()
- Updated README.md
- Bug fixes. There were problems with appendSlide() function.

**Version 1.0.0** (9 September 2016)

- init()
- appendSlide()
- on()
- getSlideIndex()

## Credits

- [NordlingArt](https://github.com/NordlingArt)

## License

[MIT](/LICENSE) - for {N} version 2.0.0+